=======
pibybit
=======


.. image:: https://img.shields.io/pypi/v/pibybit.svg
        :target: https://pypi.python.org/pypi/pibybit

.. image:: https://img.shields.io/travis/saaltfiish/pibybit.svg
        :target: https://travis-ci.com/saaltfiish/pibybit

.. image:: https://readthedocs.org/projects/pibybit/badge/?version=latest
        :target: https://pibybit.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Bybit package for PiAsset


* Free software: MIT license
* Documentation: https://pibybit.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter and the `audreyr/cookiecutter-pypackage` project template.